'use strict';

const assert = require('assert');
const _ = require('lodash');
const { ObjectId } = require('mongoose').Types;
const { CrudService } = require('naf-framework-mongoose/lib/service');
const { BusinessError, ErrorCode } = require('naf-core').Error;
const moment = require('moment');
class ChatService extends CrudService {
  constructor(ctx) {
    super(ctx, 'dock');
    this.model = this.ctx.model.Dock;
  }
  // async create(query, { sender_id, sender_name, content }) {
  //   assert(sender_name, '缺少发言人信息');
  //   assert(content, '缺少发言内容');
  //   const send_time = moment().format('YYYY-MM-DD HH:mm:ss');
  //   const res = await this.model.create({
  //     sender_id,
  //     sender_name,
  //     content,
  //     send_time,
  //   });
  //   return res;
  // }
  async apply({ id }, body) {
    const dock = await this.model.findOne({ _id: ObjectId(id) });
    if (!dock) {
      throw new BusinessError('没有查询到该对接会');
    }
    dock.apply.push({ ...body, apply_time: moment().format('YYYY-MM-DD HH:mm:ss') });
    const res = await dock.save();
    const info = _.last(res.apply);
    return info;
  }

  async check({ id, dock_id }, { status }) {
    assert(status, '请审核是否允许参加对接会');
    const dock = await this.model.findOne({ _id: ObjectId(dock_id) });
    if (!dock) {
      throw new BusinessError('没有查询到该对接会');
    }
    const user = dock.apply.id(id);
    if (!user) {
      throw new BusinessError('没有查询到用户的申请');
    }
    user.status = status;
    const res = dock.save();
    return res;
  }
}

module.exports = ChatService;
